package ru.ifmo.tracklayer.ep;

import javax.swing.SwingUtilities;

import ru.ifmo.tracklayer.gui.GUIFrame;

import com.evelopers.unimod.core.stateworks.Event;
import com.evelopers.unimod.runtime.EventProvider;
import com.evelopers.unimod.runtime.ModelEngine;
import com.evelopers.unimod.runtime.context.Parameter;
import com.evelopers.unimod.runtime.context.StateMachineContextImpl;

public class ScreenEventProvider implements EventProvider {

	/**
	 * @unimod.event.descr Window closed
	 */
    public static final String E100 = "e100";
    
    /**
	 * @unimod.event.descr Pause/Continue button pressed
	 */
    public static final String E101 = "e101";
    
    /**
	 * @unimod.event.descr Start/Stop button pressed
	 */
    public static final String E102 = "e102";
    
    /**
	 * @unimod.event.descr Initialization complete
	 */
    public static final String E103 = "e103";
	
    private static ModelEngine engine;
    
    public void init(ModelEngine engine) {
    	ScreenEventProvider.engine = engine;

        try {
        	// invoke in Swing event thread 
            SwingUtilities.invokeAndWait(new Runnable() {
                public void run() {
                	GUIFrame.getFrame().setVisible(true);
                }
            });
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
    
    /* (non-Javadoc)
     * @see com.evelopers.unimod.runtime.EventProvider#dispose()
     */
    public void dispose() {
        try {
        	// invoke in Swing event thread
            SwingUtilities.invokeAndWait(new Runnable() {
                public void run() {
                	GUIFrame.getFrame().setVisible(false);
                	GUIFrame.getFrame().dispose();
                }
            });
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    private static void fireEvent(String eventName, Parameter parameter) {
	    if (engine != null) {
	    	if (parameter == null) {
	    		engine.getEventManager().handle(new Event(eventName), StateMachineContextImpl.create());
	    	} else {
	    		engine.getEventManager().handle(new Event(eventName, new Parameter[]{parameter}), StateMachineContextImpl.create());
	    	}
	    }
    }

	public static void close() {
		fireEvent(E100, null);
	}

	public static void pauseContinue() {
		fireEvent(E101, null);
	}
	
	public static void startStop() {
		fireEvent(E102, null);
	}

	public static void inited() {
		fireEvent(E103, null);
	}
}
