package ru.ifmo.tracklayer.runner;

/**
 * This file was generated from model [Model1] on [Fri Oct 13 21:08:24 GMT 2006].
 * Do not change content of this file.
 */

import java.io.IOException;
import java.util.*;

import org.apache.commons.lang.BooleanUtils;
import org.apache.commons.lang.math.NumberUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.evelopers.common.exception.*;
import com.evelopers.unimod.core.stateworks.*;
import com.evelopers.unimod.debug.app.AppDebugger;
import com.evelopers.unimod.debug.protocol.JavaSpecificMessageCoder;
import com.evelopers.unimod.runtime.*;
import com.evelopers.unimod.runtime.context.*;
import com.evelopers.unimod.runtime.logger.SimpleLogger;

public class Model1EventProcessor extends AbstractEventProcessor {

	private ModelStructure modelStructure;

	private static final int A1 = 1;

	private static final int A2 = 2;

	private int decodeStateMachine(String sm) {

		if ("A1".equals(sm)) {
			return A1;
		} else

		if ("A2".equals(sm)) {
			return A2;
		}

		return -1;
	}

	private A1EventProcessor _A1;

	private A2EventProcessor _A2;

	public Model1EventProcessor() {
		modelStructure = new Model1ModelStructure();

		_A1 = new A1EventProcessor();
		_A2 = new A2EventProcessor();
	}

	public static void run(int debuggerPort, boolean debuggerSuspend)
			throws InterruptedException, EventProcessorException,
			CommonException, IOException {

		/* Create runtime engine */
		ModelEngine engine = createModelEngine(true);

		/* Setup logger */
		final Log log = LogFactory.getLog(Model1EventProcessor.class);
		engine.getEventProcessor().addEventProcessorListener(
				new SimpleLogger(log));

		/* Setup exception handler */
		engine.getEventProcessor().addExceptionHandler(new ExceptionHandler() {
			public void handleException(StateMachineContext context,
					SystemException e) {
				log.fatal(e.getChainedMessage(), e.getRootException());
			}
		});

		if (debuggerPort > 0) {
			AppDebugger d = new AppDebugger(debuggerPort, debuggerSuspend,
					new JavaSpecificMessageCoder(), engine);
			d.start();
		}
		engine.start();
	}

	public static void main(String[] args) throws Exception {
		int debuggerPort = NumberUtils.stringToInt(System
				.getProperty("debugger.port"), -1);
		boolean debuggerSuspend = BooleanUtils.toBoolean(System
				.getProperty("debugger.suspend"));
		Model1EventProcessor.run(debuggerPort, debuggerSuspend);
	}

	public static ModelEngine createModelEngine(boolean useEventQueue)
			throws CommonException {
		ObjectsManager objectsManager = new ObjectsManager();
		return ModelEngine.createStandAlone(
				useEventQueue ? (EventManager) new QueuedHandler()
						: (EventManager) new StrictHandler(),
				new Model1EventProcessor(), objectsManager
						.getControlledObjectsManager(), objectsManager
						.getEventProvidersManager());
	}

	public static class ObjectsManager {
		private ru.ifmo.tracklayer.co.Tracklayer o1 = null;

		private ru.ifmo.tracklayer.co.Screen o2 = null;

		private ru.ifmo.tracklayer.ep.ScreenEventProvider p1 = null;

		private ru.ifmo.tracklayer.ep.TracklayerEventProvider p2 = null;

		private ControlledObjectsManager controlledObjectsManager = new ControlledObjectsManagerImpl();

		private EventProvidersManager eventProvidersManager = new EventProvidersManagerImpl();

		public ControlledObjectsManager getControlledObjectsManager() {
			return controlledObjectsManager;
		}

		public EventProvidersManager getEventProvidersManager() {
			return eventProvidersManager;
		}

		private class ControlledObjectsManagerImpl implements
				ControlledObjectsManager {
			public void init(ModelEngine engine) throws CommonException {
			}

			public void dispose() {
			}

			public ControlledObject getControlledObject(String coName) {
				if (StringUtils.equals(coName, "o1")) {
					if (o1 == null) {
						o1 = new ru.ifmo.tracklayer.co.Tracklayer();
					}
					return o1;
				}
				if (StringUtils.equals(coName, "o2")) {
					if (o2 == null) {
						o2 = new ru.ifmo.tracklayer.co.Screen();
					}
					return o2;
				}
				throw new IllegalArgumentException(
						"Controlled object with name [" + coName
								+ "] wasn't found");
			}
		}

		private class EventProvidersManagerImpl implements
				EventProvidersManager {
			private List nonameEventProviders = new ArrayList();

			public void init(ModelEngine engine) throws CommonException {
				EventProvider ep;
				ep = getEventProvider("p1");
				ep.init(engine);
				ep = getEventProvider("p2");
				ep.init(engine);
			}

			public void dispose() {
				EventProvider ep;
				ep = getEventProvider("p1");
				ep.dispose();
				ep = getEventProvider("p2");
				ep.dispose();
				for (Iterator i = nonameEventProviders.iterator(); i.hasNext();) {
					ep = (EventProvider) i.next();
					ep.dispose();
				}
			}

			public EventProvider getEventProvider(String epName) {
				if (StringUtils.equals(epName, "p1")) {
					if (p1 == null) {
						p1 = new ru.ifmo.tracklayer.ep.ScreenEventProvider();
					}
					return p1;
				}
				if (StringUtils.equals(epName, "p2")) {
					if (p2 == null) {
						p2 = new ru.ifmo.tracklayer.ep.TracklayerEventProvider();
					}
					return p2;
				}
				throw new IllegalArgumentException("Event provider with name ["
						+ epName + "] wasn't found");
			}
		}
	}

	public ModelStructure getModelStructure() {
		return modelStructure;
	}

	public void setControlledObjectsMap(
			ControlledObjectsMap controlledObjectsMap) {
		super.setControlledObjectsMap(controlledObjectsMap);

		_A1.init(controlledObjectsMap);
		_A2.init(controlledObjectsMap);
	}

	protected StateMachineConfig process(Event event,
			StateMachineContext context, StateMachinePath path,
			StateMachineConfig config) throws SystemException {

		// get state machine from path
		int sm = decodeStateMachine(path.getStateMachine());

		try {
			switch (sm) {
			case A1:
				return _A1.process(event, context, path, config);
			case A2:
				return _A2.process(event, context, path, config);
			default:
				throw new EventProcessorException("Unknown state machine ["
						+ path.getStateMachine() + "]");
			}
		} catch (Exception e) {
			if (e instanceof SystemException) {
				throw (SystemException) e;
			} else {
				throw new SystemException(e);
			}
		}
	}

	protected StateMachineConfig transiteToStableState(
			StateMachineContext context, StateMachinePath path,
			StateMachineConfig config) throws SystemException {

		// get state machine from path
		int sm = decodeStateMachine(path.getStateMachine());

		try {
			switch (sm) {
			case A1:
				return _A1.transiteToStableState(context, path, config);
			case A2:
				return _A2.transiteToStableState(context, path, config);
			default:
				throw new EventProcessorException("Unknown state machine ["
						+ path.getStateMachine() + "]");
			}
		} catch (Exception e) {
			if (e instanceof SystemException) {
				throw (SystemException) e;
			} else {
				throw new SystemException(e);
			}
		}
	}

	private class Model1ModelStructure implements ModelStructure {
		private Map configManagers = new HashMap();

		private Model1ModelStructure() {
			configManagers
					.put(
							"A1",
							new com.evelopers.unimod.runtime.config.DistinguishConfigManager());
			configManagers
					.put(
							"A2",
							new com.evelopers.unimod.runtime.config.DistinguishConfigManager());
		}

		public StateMachinePath getRootPath() throws EventProcessorException {
			return new StateMachinePath("A1");
		}

		public StateMachineConfigManager getConfigManager(String stateMachine)
				throws EventProcessorException {
			return (StateMachineConfigManager) configManagers.get(stateMachine);
		}

		public StateMachineConfig getTopConfig(String stateMachine)
				throws EventProcessorException {
			int sm = decodeStateMachine(stateMachine);

			switch (sm) {
			case A1:
				return new StateMachineConfig("Top");
			case A2:
				return new StateMachineConfig("Top");
			default:
				throw new EventProcessorException("Unknown state machine ["
						+ stateMachine + "]");
			}
		}

		public boolean isFinal(String stateMachine, StateMachineConfig config)
				throws EventProcessorException {
			/* Get state machine from path */
			int sm = decodeStateMachine(stateMachine);
			int state;
			switch (sm) {
			case A1:
				state = _A1.decodeState(config.getActiveState());
				switch (state) {
				case A1EventProcessor.s2:
					return true;
				default:
					return false;
				}
			case A2:
				state = _A2.decodeState(config.getActiveState());
				switch (state) {
				default:
					return false;
				}
			default:
				throw new EventProcessorException("Unknown state machine ["
						+ stateMachine + "]");
			}
		}
	}

	private class A1EventProcessor {

		// states
		private static final int Top = 1;

		private static final int _1__Initialization = 2;

		private static final int _3__Pause = 3;

		private static final int s1 = 4;

		private static final int s2 = 5;

		private static final int _2__Work = 6;

		private int decodeState(String state) {

			if ("Top".equals(state)) {
				return Top;
			} else

			if ("1. Initialization".equals(state)) {
				return _1__Initialization;
			} else

			if ("3. Pause".equals(state)) {
				return _3__Pause;
			} else

			if ("s1".equals(state)) {
				return s1;
			} else

			if ("s2".equals(state)) {
				return s2;
			} else

			if ("2. Work".equals(state)) {
				return _2__Work;
			}

			return -1;
		}

		// events
		private static final int e101 = 1;

		private static final int e100 = 2;

		private static final int e102 = 3;

		private int decodeEvent(String event) {

			if ("e101".equals(event)) {
				return e101;
			} else

			if ("e100".equals(event)) {
				return e100;
			} else

			if ("e102".equals(event)) {
				return e102;
			}

			return -1;
		}

		private ru.ifmo.tracklayer.co.Tracklayer o1;

		private ru.ifmo.tracklayer.co.Screen o2;

		private void init(ControlledObjectsMap controlledObjectsMap) {
			o1 = (ru.ifmo.tracklayer.co.Tracklayer) controlledObjectsMap
					.getControlledObject("o1");
			o2 = (ru.ifmo.tracklayer.co.Screen) controlledObjectsMap
					.getControlledObject("o2");
		}

		private StateMachineConfig process(Event event,
				StateMachineContext context, StateMachinePath path,
				StateMachineConfig config) throws Exception {
			config = lookForTransition(event, context, path, config);

			config = transiteToStableState(context, path, config);

			// execute included state machines
			executeSubmachines(event, context, path, config);

			return config;
		}

		private void executeSubmachines(Event event,
				StateMachineContext context, StateMachinePath path,
				StateMachineConfig config) throws Exception {
			int state = decodeState(config.getActiveState());

			while (true) {
				switch (state) {
				case _1__Initialization:

					return;
				case _3__Pause:

					return;
				case s1:

					return;
				case s2:

					return;
				case _2__Work:
					// 2. Work includes A2

					fireBeforeSubmachineExecution(context, event, path,
							"2. Work", "A2");

					Model1EventProcessor.this.process(event, context,
							new StateMachinePath(path, "2. Work", "A2"));

					fireAfterSubmachineExecution(context, event, path,
							"2. Work", "A2");

					return;
				default:
					throw new EventProcessorException("State with name ["
							+ config.getActiveState()
							+ "] is unknown for state machine [A1]");
				}
			}
		}

		private StateMachineConfig transiteToStableState(
				StateMachineContext context, StateMachinePath path,
				StateMachineConfig config) throws Exception {

			int s = decodeState(config.getActiveState());
			Event event;

			switch (s) {
			case Top:

				fireComeToState(context, path, "s1");

				// s1->1. Initialization [true]/
				event = Event.NO_EVENT;
				fireTransitionFound(context, path, "s1", event,
						"s1#1. Initialization##true");

				fireComeToState(context, path, "1. Initialization");

				// 1. Initialization [o2.z1, o2.z4]
				fireBeforeOutputActionExecution(context, path,
						"s1#1. Initialization##true", "o2.z1");

				o2.z1(context);

				fireAfterOutputActionExecution(context, path,
						"s1#1. Initialization##true", "o2.z1");
				fireBeforeOutputActionExecution(context, path,
						"s1#1. Initialization##true", "o2.z4");

				o2.z4(context);

				fireAfterOutputActionExecution(context, path,
						"s1#1. Initialization##true", "o2.z4");

				return new StateMachineConfig("1. Initialization");
			}

			return config;
		}

		private StateMachineConfig lookForTransition(Event event,
				StateMachineContext context, StateMachinePath path,
				StateMachineConfig config) throws Exception {

			BitSet calculatedInputActions = new BitSet(0);

			int s = decodeState(config.getActiveState());
			int e = decodeEvent(event.getName());

			while (true) {
				switch (s) {
				case _1__Initialization:

					switch (e) {
					case e100:

						// 1. Initialization->s2 e100[true]/

						fireTransitionCandidate(context, path,
								"1. Initialization", event,
								"1. Initialization#s2#e100#true");

						fireTransitionFound(context, path, "1. Initialization",
								event, "1. Initialization#s2#e100#true");

						fireComeToState(context, path, "s2");

						// s2 []
						return new StateMachineConfig("s2");

					case e102:

						// 1. Initialization->2. Work e102[true]/

						fireTransitionCandidate(context, path,
								"1. Initialization", event,
								"1. Initialization#2. Work#e102#true");

						fireTransitionFound(context, path, "1. Initialization",
								event, "1. Initialization#2. Work#e102#true");

						fireComeToState(context, path, "2. Work");

						// 2. Work [o2.z2, o2.z4]
						fireBeforeOutputActionExecution(context, path,
								"1. Initialization#2. Work#e102#true", "o2.z2");

						o2.z2(context);

						fireAfterOutputActionExecution(context, path,
								"1. Initialization#2. Work#e102#true", "o2.z2");
						fireBeforeOutputActionExecution(context, path,
								"1. Initialization#2. Work#e102#true", "o2.z4");

						o2.z4(context);

						fireAfterOutputActionExecution(context, path,
								"1. Initialization#2. Work#e102#true", "o2.z4");
						return new StateMachineConfig("2. Work");

					default:

						// transition not found
						return config;
					}

				case _3__Pause:

					switch (e) {
					case e101:

						// 3. Pause->2. Work e101[true]/

						fireTransitionCandidate(context, path, "3. Pause",
								event, "3. Pause#2. Work#e101#true");

						fireTransitionFound(context, path, "3. Pause", event,
								"3. Pause#2. Work#e101#true");

						fireComeToState(context, path, "2. Work");

						// 2. Work [o2.z2, o2.z4]
						fireBeforeOutputActionExecution(context, path,
								"3. Pause#2. Work#e101#true", "o2.z2");

						o2.z2(context);

						fireAfterOutputActionExecution(context, path,
								"3. Pause#2. Work#e101#true", "o2.z2");
						fireBeforeOutputActionExecution(context, path,
								"3. Pause#2. Work#e101#true", "o2.z4");

						o2.z4(context);

						fireAfterOutputActionExecution(context, path,
								"3. Pause#2. Work#e101#true", "o2.z4");
						return new StateMachineConfig("2. Work");

					case e100:

						// 3. Pause->s2 e100[true]/

						fireTransitionCandidate(context, path, "3. Pause",
								event, "3. Pause#s2#e100#true");

						fireTransitionFound(context, path, "3. Pause", event,
								"3. Pause#s2#e100#true");

						fireComeToState(context, path, "s2");

						// s2 []
						return new StateMachineConfig("s2");

					case e102:

						// 3. Pause->1. Initialization e102[true]/

						fireTransitionCandidate(context, path, "3. Pause",
								event, "3. Pause#1. Initialization#e102#true");

						fireTransitionFound(context, path, "3. Pause", event,
								"3. Pause#1. Initialization#e102#true");

						fireComeToState(context, path, "1. Initialization");

						// 1. Initialization [o2.z1, o2.z4]
						fireBeforeOutputActionExecution(context, path,
								"3. Pause#1. Initialization#e102#true", "o2.z1");

						o2.z1(context);

						fireAfterOutputActionExecution(context, path,
								"3. Pause#1. Initialization#e102#true", "o2.z1");
						fireBeforeOutputActionExecution(context, path,
								"3. Pause#1. Initialization#e102#true", "o2.z4");

						o2.z4(context);

						fireAfterOutputActionExecution(context, path,
								"3. Pause#1. Initialization#e102#true", "o2.z4");
						return new StateMachineConfig("1. Initialization");

					default:

						// transition not found
						return config;
					}

				case _2__Work:

					switch (e) {
					case e101:

						// 2. Work->3. Pause e101[true]/

						fireTransitionCandidate(context, path, "2. Work",
								event, "2. Work#3. Pause#e101#true");

						fireTransitionFound(context, path, "2. Work", event,
								"2. Work#3. Pause#e101#true");

						fireComeToState(context, path, "3. Pause");

						// 3. Pause [o2.z3, o2.z4]
						fireBeforeOutputActionExecution(context, path,
								"2. Work#3. Pause#e101#true", "o2.z3");

						o2.z3(context);

						fireAfterOutputActionExecution(context, path,
								"2. Work#3. Pause#e101#true", "o2.z3");
						fireBeforeOutputActionExecution(context, path,
								"2. Work#3. Pause#e101#true", "o2.z4");

						o2.z4(context);

						fireAfterOutputActionExecution(context, path,
								"2. Work#3. Pause#e101#true", "o2.z4");
						return new StateMachineConfig("3. Pause");

					case e100:

						// 2. Work->s2 e100[true]/

						fireTransitionCandidate(context, path, "2. Work",
								event, "2. Work#s2#e100#true");

						fireTransitionFound(context, path, "2. Work", event,
								"2. Work#s2#e100#true");

						fireComeToState(context, path, "s2");

						// s2 []
						return new StateMachineConfig("s2");

					case e102:

						// 2. Work->1. Initialization e102[true]/

						fireTransitionCandidate(context, path, "2. Work",
								event, "2. Work#1. Initialization#e102#true");

						fireTransitionFound(context, path, "2. Work", event,
								"2. Work#1. Initialization#e102#true");

						fireComeToState(context, path, "1. Initialization");

						// 1. Initialization [o2.z1, o2.z4]
						fireBeforeOutputActionExecution(context, path,
								"2. Work#1. Initialization#e102#true", "o2.z1");

						o2.z1(context);

						fireAfterOutputActionExecution(context, path,
								"2. Work#1. Initialization#e102#true", "o2.z1");
						fireBeforeOutputActionExecution(context, path,
								"2. Work#1. Initialization#e102#true", "o2.z4");

						o2.z4(context);

						fireAfterOutputActionExecution(context, path,
								"2. Work#1. Initialization#e102#true", "o2.z4");
						return new StateMachineConfig("1. Initialization");

					default:

						// transition not found
						return config;
					}

				default:
					throw new EventProcessorException(
							"Incorrect stable state ["
									+ config.getActiveState()
									+ "] in state machine [A1]");
				}
			}
		}

	}

	private class A2EventProcessor {

		// states
		private static final int Top = 1;

		private static final int _2__Moving_forward = 2;

		private static final int _7__Shutting_down = 3;

		private static final int _3__Taking_off_old_rails = 4;

		private static final int s1 = 5;

		private static final int _6__Loading = 6;

		private static final int _1__Initialization = 7;

		private static final int _4__Putting_new_rails = 8;

		private static final int _5__Moving_backward = 9;

		private int decodeState(String state) {

			if ("Top".equals(state)) {
				return Top;
			} else

			if ("2. Moving forward".equals(state)) {
				return _2__Moving_forward;
			} else

			if ("7. Shutting down".equals(state)) {
				return _7__Shutting_down;
			} else

			if ("3. Taking off old rails".equals(state)) {
				return _3__Taking_off_old_rails;
			} else

			if ("s1".equals(state)) {
				return s1;
			} else

			if ("6. Loading".equals(state)) {
				return _6__Loading;
			} else

			if ("1. Initialization".equals(state)) {
				return _1__Initialization;
			} else

			if ("4. Putting new rails".equals(state)) {
				return _4__Putting_new_rails;
			} else

			if ("5. Moving backward".equals(state)) {
				return _5__Moving_backward;
			}

			return -1;
		}

		// events
		private static final int e203 = 1;

		private static final int e201 = 2;

		private static final int e101 = 3;

		private static final int e204 = 4;

		private static final int e202 = 5;

		private static final int e200 = 6;

		private static final int e102 = 7;

		private int decodeEvent(String event) {

			if ("e203".equals(event)) {
				return e203;
			} else

			if ("e201".equals(event)) {
				return e201;
			} else

			if ("e101".equals(event)) {
				return e101;
			} else

			if ("e204".equals(event)) {
				return e204;
			} else

			if ("e202".equals(event)) {
				return e202;
			} else

			if ("e200".equals(event)) {
				return e200;
			} else

			if ("e102".equals(event)) {
				return e102;
			}

			return -1;
		}

		private ru.ifmo.tracklayer.co.Tracklayer o1;

		private ru.ifmo.tracklayer.co.Screen o2;

		private void init(ControlledObjectsMap controlledObjectsMap) {
			o1 = (ru.ifmo.tracklayer.co.Tracklayer) controlledObjectsMap
					.getControlledObject("o1");
			o2 = (ru.ifmo.tracklayer.co.Screen) controlledObjectsMap
					.getControlledObject("o2");
		}

		private StateMachineConfig process(Event event,
				StateMachineContext context, StateMachinePath path,
				StateMachineConfig config) throws Exception {
			config = lookForTransition(event, context, path, config);

			config = transiteToStableState(context, path, config);

			// execute included state machines
			executeSubmachines(event, context, path, config);

			return config;
		}

		private void executeSubmachines(Event event,
				StateMachineContext context, StateMachinePath path,
				StateMachineConfig config) throws Exception {
			int state = decodeState(config.getActiveState());

			while (true) {
				switch (state) {
				case _2__Moving_forward:

					return;
				case _7__Shutting_down:

					return;
				case _3__Taking_off_old_rails:

					return;
				case s1:

					return;
				case _6__Loading:

					return;
				case _1__Initialization:

					return;
				case _4__Putting_new_rails:

					return;
				case _5__Moving_backward:

					return;
				default:
					throw new EventProcessorException("State with name ["
							+ config.getActiveState()
							+ "] is unknown for state machine [A2]");
				}
			}
		}

		private StateMachineConfig transiteToStableState(
				StateMachineContext context, StateMachinePath path,
				StateMachineConfig config) throws Exception {

			int s = decodeState(config.getActiveState());
			Event event;

			switch (s) {
			case Top:

				fireComeToState(context, path, "s1");

				// s1->1. Initialization [true]/
				event = Event.NO_EVENT;
				fireTransitionFound(context, path, "s1", event,
						"s1#1. Initialization##true");

				fireComeToState(context, path, "1. Initialization");

				// 1. Initialization [o1.z6]
				fireBeforeOutputActionExecution(context, path,
						"s1#1. Initialization##true", "o1.z6");

				o1.z6(context);

				fireAfterOutputActionExecution(context, path,
						"s1#1. Initialization##true", "o1.z6");

				return new StateMachineConfig("1. Initialization");
			}

			return config;
		}

		private StateMachineConfig lookForTransition(Event event,
				StateMachineContext context, StateMachinePath path,
				StateMachineConfig config) throws Exception {

			int

			o1_x1 = 0;

			BitSet calculatedInputActions = new BitSet(1);

			int s = decodeState(config.getActiveState());
			int e = decodeEvent(event.getName());

			while (true) {
				switch (s) {
				case _2__Moving_forward:

					switch (e) {
					case e203:

						// 2. Moving forward->2. Moving forward e203[true]/o2.z4

						fireTransitionCandidate(context, path,
								"2. Moving forward", event,
								"2. Moving forward#2. Moving forward#e203#true");

						fireTransitionFound(context, path, "2. Moving forward",
								event,
								"2. Moving forward#2. Moving forward#e203#true");

						fireBeforeOutputActionExecution(
								context,
								path,
								"2. Moving forward#2. Moving forward#e203#true",
								"o2.z4");

						o2.z4(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"2. Moving forward#2. Moving forward#e203#true",
								"o2.z4");

						fireComeToState(context, path, "2. Moving forward");

						// 2. Moving forward [o1.z1]
						fireBeforeOutputActionExecution(
								context,
								path,
								"2. Moving forward#2. Moving forward#e203#true",
								"o1.z1");

						o1.z1(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"2. Moving forward#2. Moving forward#e203#true",
								"o1.z1");
						return new StateMachineConfig("2. Moving forward");

					case e201:

						// 2. Moving forward->4. Putting new rails e201[true]/

						fireTransitionCandidate(context, path,
								"2. Moving forward", event,
								"2. Moving forward#4. Putting new rails#e201#true");

						fireTransitionFound(context, path, "2. Moving forward",
								event,
								"2. Moving forward#4. Putting new rails#e201#true");

						fireComeToState(context, path, "4. Putting new rails");

						// 4. Putting new rails [o1.z3]
						fireBeforeOutputActionExecution(
								context,
								path,
								"2. Moving forward#4. Putting new rails#e201#true",
								"o1.z3");

						o1.z3(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"2. Moving forward#4. Putting new rails#e201#true",
								"o1.z3");
						return new StateMachineConfig("4. Putting new rails");

					case e101:

						// 2. Moving forward->2. Moving forward e101[true]/

						fireTransitionCandidate(context, path,
								"2. Moving forward", event,
								"2. Moving forward#2. Moving forward#e101#true");

						fireTransitionFound(context, path, "2. Moving forward",
								event,
								"2. Moving forward#2. Moving forward#e101#true");

						fireComeToState(context, path, "2. Moving forward");

						// 2. Moving forward [o1.z1]
						fireBeforeOutputActionExecution(
								context,
								path,
								"2. Moving forward#2. Moving forward#e101#true",
								"o1.z1");

						o1.z1(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"2. Moving forward#2. Moving forward#e101#true",
								"o1.z1");
						return new StateMachineConfig("2. Moving forward");

					case e202:

						// 2. Moving forward->7. Shutting down e202[true]/

						fireTransitionCandidate(context, path,
								"2. Moving forward", event,
								"2. Moving forward#7. Shutting down#e202#true");

						fireTransitionFound(context, path, "2. Moving forward",
								event,
								"2. Moving forward#7. Shutting down#e202#true");

						fireComeToState(context, path, "7. Shutting down");

						// 7. Shutting down [o1.z2]
						fireBeforeOutputActionExecution(context, path,
								"2. Moving forward#7. Shutting down#e202#true",
								"o1.z2");

						o1.z2(context);

						fireAfterOutputActionExecution(context, path,
								"2. Moving forward#7. Shutting down#e202#true",
								"o1.z2");
						return new StateMachineConfig("7. Shutting down");

					case e200:

						// 2. Moving forward->3. Taking off old rails e200[true]/

						fireTransitionCandidate(context, path,
								"2. Moving forward", event,
								"2. Moving forward#3. Taking off old rails#e200#true");

						fireTransitionFound(context, path, "2. Moving forward",
								event,
								"2. Moving forward#3. Taking off old rails#e200#true");

						fireComeToState(context, path,
								"3. Taking off old rails");

						// 3. Taking off old rails [o1.z4]
						fireBeforeOutputActionExecution(
								context,
								path,
								"2. Moving forward#3. Taking off old rails#e200#true",
								"o1.z4");

						o1.z4(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"2. Moving forward#3. Taking off old rails#e200#true",
								"o1.z4");
						return new StateMachineConfig("3. Taking off old rails");

					case e102:

						// 2. Moving forward->1. Initialization e102[true]/

						fireTransitionCandidate(context, path,
								"2. Moving forward", event,
								"2. Moving forward#1. Initialization#e102#true");

						fireTransitionFound(context, path, "2. Moving forward",
								event,
								"2. Moving forward#1. Initialization#e102#true");

						fireComeToState(context, path, "1. Initialization");

						// 1. Initialization [o1.z6]
						fireBeforeOutputActionExecution(
								context,
								path,
								"2. Moving forward#1. Initialization#e102#true",
								"o1.z6");

						o1.z6(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"2. Moving forward#1. Initialization#e102#true",
								"o1.z6");
						return new StateMachineConfig("1. Initialization");

					default:

						// transition not found
						return config;
					}

				case _7__Shutting_down:

					switch (e) {
					case e203:

						// 7. Shutting down->7. Shutting down e203[true]/o2.z4

						fireTransitionCandidate(context, path,
								"7. Shutting down", event,
								"7. Shutting down#7. Shutting down#e203#true");

						fireTransitionFound(context, path, "7. Shutting down",
								event,
								"7. Shutting down#7. Shutting down#e203#true");

						fireBeforeOutputActionExecution(context, path,
								"7. Shutting down#7. Shutting down#e203#true",
								"o2.z4");

						o2.z4(context);

						fireAfterOutputActionExecution(context, path,
								"7. Shutting down#7. Shutting down#e203#true",
								"o2.z4");

						fireComeToState(context, path, "7. Shutting down");

						// 7. Shutting down [o1.z2]
						fireBeforeOutputActionExecution(context, path,
								"7. Shutting down#7. Shutting down#e203#true",
								"o1.z2");

						o1.z2(context);

						fireAfterOutputActionExecution(context, path,
								"7. Shutting down#7. Shutting down#e203#true",
								"o1.z2");
						return new StateMachineConfig("7. Shutting down");

					case e101:

						// 7. Shutting down->7. Shutting down e101[true]/

						fireTransitionCandidate(context, path,
								"7. Shutting down", event,
								"7. Shutting down#7. Shutting down#e101#true");

						fireTransitionFound(context, path, "7. Shutting down",
								event,
								"7. Shutting down#7. Shutting down#e101#true");

						fireComeToState(context, path, "7. Shutting down");

						// 7. Shutting down [o1.z2]
						fireBeforeOutputActionExecution(context, path,
								"7. Shutting down#7. Shutting down#e101#true",
								"o1.z2");

						o1.z2(context);

						fireAfterOutputActionExecution(context, path,
								"7. Shutting down#7. Shutting down#e101#true",
								"o1.z2");
						return new StateMachineConfig("7. Shutting down");

					case e102:

						// 7. Shutting down->1. Initialization e102[true]/

						fireTransitionCandidate(context, path,
								"7. Shutting down", event,
								"7. Shutting down#1. Initialization#e102#true");

						fireTransitionFound(context, path, "7. Shutting down",
								event,
								"7. Shutting down#1. Initialization#e102#true");

						fireComeToState(context, path, "1. Initialization");

						// 1. Initialization [o1.z6]
						fireBeforeOutputActionExecution(context, path,
								"7. Shutting down#1. Initialization#e102#true",
								"o1.z6");

						o1.z6(context);

						fireAfterOutputActionExecution(context, path,
								"7. Shutting down#1. Initialization#e102#true",
								"o1.z6");
						return new StateMachineConfig("1. Initialization");

					default:

						// transition not found
						return config;
					}

				case _3__Taking_off_old_rails:

					switch (e) {
					case e203:

						// 3. Taking off old rails->4. Putting new rails e203[true]/o2.z4

						fireTransitionCandidate(context, path,
								"3. Taking off old rails", event,
								"3. Taking off old rails#4. Putting new rails#e203#true");

						fireTransitionFound(context, path,
								"3. Taking off old rails", event,
								"3. Taking off old rails#4. Putting new rails#e203#true");

						fireBeforeOutputActionExecution(
								context,
								path,
								"3. Taking off old rails#4. Putting new rails#e203#true",
								"o2.z4");

						o2.z4(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"3. Taking off old rails#4. Putting new rails#e203#true",
								"o2.z4");

						fireComeToState(context, path, "4. Putting new rails");

						// 4. Putting new rails [o1.z3]
						fireBeforeOutputActionExecution(
								context,
								path,
								"3. Taking off old rails#4. Putting new rails#e203#true",
								"o1.z3");

						o1.z3(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"3. Taking off old rails#4. Putting new rails#e203#true",
								"o1.z3");
						return new StateMachineConfig("4. Putting new rails");

					case e101:

						// 3. Taking off old rails->3. Taking off old rails e101[true]/

						fireTransitionCandidate(context, path,
								"3. Taking off old rails", event,
								"3. Taking off old rails#3. Taking off old rails#e101#true");

						fireTransitionFound(context, path,
								"3. Taking off old rails", event,
								"3. Taking off old rails#3. Taking off old rails#e101#true");

						fireComeToState(context, path,
								"3. Taking off old rails");

						// 3. Taking off old rails [o1.z4]
						fireBeforeOutputActionExecution(
								context,
								path,
								"3. Taking off old rails#3. Taking off old rails#e101#true",
								"o1.z4");

						o1.z4(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"3. Taking off old rails#3. Taking off old rails#e101#true",
								"o1.z4");
						return new StateMachineConfig("3. Taking off old rails");

					case e102:

						// 3. Taking off old rails->1. Initialization e102[true]/

						fireTransitionCandidate(context, path,
								"3. Taking off old rails", event,
								"3. Taking off old rails#1. Initialization#e102#true");

						fireTransitionFound(context, path,
								"3. Taking off old rails", event,
								"3. Taking off old rails#1. Initialization#e102#true");

						fireComeToState(context, path, "1. Initialization");

						// 1. Initialization [o1.z6]
						fireBeforeOutputActionExecution(
								context,
								path,
								"3. Taking off old rails#1. Initialization#e102#true",
								"o1.z6");

						o1.z6(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"3. Taking off old rails#1. Initialization#e102#true",
								"o1.z6");
						return new StateMachineConfig("1. Initialization");

					default:

						// transition not found
						return config;
					}

				case _6__Loading:

					switch (e) {
					case e203:

						// 6. Loading->6. Loading e203[true]/o2.z4

						fireTransitionCandidate(context, path, "6. Loading",
								event, "6. Loading#6. Loading#e203#true");

						fireTransitionFound(context, path, "6. Loading", event,
								"6. Loading#6. Loading#e203#true");

						fireBeforeOutputActionExecution(context, path,
								"6. Loading#6. Loading#e203#true", "o2.z4");

						o2.z4(context);

						fireAfterOutputActionExecution(context, path,
								"6. Loading#6. Loading#e203#true", "o2.z4");

						fireComeToState(context, path, "6. Loading");

						// 6. Loading [o1.z5]
						fireBeforeOutputActionExecution(context, path,
								"6. Loading#6. Loading#e203#true", "o1.z5");

						o1.z5(context);

						fireAfterOutputActionExecution(context, path,
								"6. Loading#6. Loading#e203#true", "o1.z5");
						return new StateMachineConfig("6. Loading");

					case e101:

						// 6. Loading->6. Loading e101[true]/

						fireTransitionCandidate(context, path, "6. Loading",
								event, "6. Loading#6. Loading#e101#true");

						fireTransitionFound(context, path, "6. Loading", event,
								"6. Loading#6. Loading#e101#true");

						fireComeToState(context, path, "6. Loading");

						// 6. Loading [o1.z5]
						fireBeforeOutputActionExecution(context, path,
								"6. Loading#6. Loading#e101#true", "o1.z5");

						o1.z5(context);

						fireAfterOutputActionExecution(context, path,
								"6. Loading#6. Loading#e101#true", "o1.z5");
						return new StateMachineConfig("6. Loading");

					case e204:

						// 6. Loading->2. Moving forward e204[true]/

						fireTransitionCandidate(context, path, "6. Loading",
								event, "6. Loading#2. Moving forward#e204#true");

						fireTransitionFound(context, path, "6. Loading", event,
								"6. Loading#2. Moving forward#e204#true");

						fireComeToState(context, path, "2. Moving forward");

						// 2. Moving forward [o1.z1]
						fireBeforeOutputActionExecution(context, path,
								"6. Loading#2. Moving forward#e204#true",
								"o1.z1");

						o1.z1(context);

						fireAfterOutputActionExecution(context, path,
								"6. Loading#2. Moving forward#e204#true",
								"o1.z1");
						return new StateMachineConfig("2. Moving forward");

					case e102:

						// 6. Loading->1. Initialization e102[true]/

						fireTransitionCandidate(context, path, "6. Loading",
								event, "6. Loading#1. Initialization#e102#true");

						fireTransitionFound(context, path, "6. Loading", event,
								"6. Loading#1. Initialization#e102#true");

						fireComeToState(context, path, "1. Initialization");

						// 1. Initialization [o1.z6]
						fireBeforeOutputActionExecution(context, path,
								"6. Loading#1. Initialization#e102#true",
								"o1.z6");

						o1.z6(context);

						fireAfterOutputActionExecution(context, path,
								"6. Loading#1. Initialization#e102#true",
								"o1.z6");
						return new StateMachineConfig("1. Initialization");

					default:

						// transition not found
						return config;
					}

				case _1__Initialization:

					switch (e) {
					case e203:

						// 1. Initialization->2. Moving forward e203[o1.x1>0]/o2.z4

						fireTransitionCandidate(context, path,
								"1. Initialization", event,
								"1. Initialization#2. Moving forward#e203#o1.x1>0");

						if (!isInputActionCalculated(calculatedInputActions,
								_o1_x1)) {

							fireBeforeInputActionExecution(
									context,
									path,
									"1. Initialization#2. Moving forward#e203#o1.x1>0",
									"o1.x1");

							o1_x1 = o1.x1(context);

							fireAfterInputActionExecution(
									context,
									path,
									"1. Initialization#2. Moving forward#e203#o1.x1>0",
									"o1.x1", new Integer(o1_x1));
						}

						if (o1_x1 > 0) {

							fireTransitionFound(context, path,
									"1. Initialization", event,
									"1. Initialization#2. Moving forward#e203#o1.x1>0");

							fireBeforeOutputActionExecution(
									context,
									path,
									"1. Initialization#2. Moving forward#e203#o1.x1>0",
									"o2.z4");

							o2.z4(context);

							fireAfterOutputActionExecution(
									context,
									path,
									"1. Initialization#2. Moving forward#e203#o1.x1>0",
									"o2.z4");

							fireComeToState(context, path, "2. Moving forward");

							// 2. Moving forward [o1.z1]
							fireBeforeOutputActionExecution(
									context,
									path,
									"1. Initialization#2. Moving forward#e203#o1.x1>0",
									"o1.z1");

							o1.z1(context);

							fireAfterOutputActionExecution(
									context,
									path,
									"1. Initialization#2. Moving forward#e203#o1.x1>0",
									"o1.z1");
							return new StateMachineConfig("2. Moving forward");

						}
						// 1. Initialization->5. Moving backward e203[o1.x1 <= 0]/o2.z4

						fireTransitionCandidate(context, path,
								"1. Initialization", event,
								"1. Initialization#5. Moving backward#e203#o1.x1 <= 0");

						if (o1_x1 <= 0) {

							fireTransitionFound(context, path,
									"1. Initialization", event,
									"1. Initialization#5. Moving backward#e203#o1.x1 <= 0");

							fireBeforeOutputActionExecution(
									context,
									path,
									"1. Initialization#5. Moving backward#e203#o1.x1 <= 0",
									"o2.z4");

							o2.z4(context);

							fireAfterOutputActionExecution(
									context,
									path,
									"1. Initialization#5. Moving backward#e203#o1.x1 <= 0",
									"o2.z4");

							fireComeToState(context, path, "5. Moving backward");

							// 5. Moving backward [o1.z2]
							fireBeforeOutputActionExecution(
									context,
									path,
									"1. Initialization#5. Moving backward#e203#o1.x1 <= 0",
									"o1.z2");

							o1.z2(context);

							fireAfterOutputActionExecution(
									context,
									path,
									"1. Initialization#5. Moving backward#e203#o1.x1 <= 0",
									"o1.z2");
							return new StateMachineConfig("5. Moving backward");

						}

						// transition not found
						return config;
					case e101:

						// 1. Initialization->1. Initialization e101[true]/

						fireTransitionCandidate(context, path,
								"1. Initialization", event,
								"1. Initialization#1. Initialization#e101#true");

						fireTransitionFound(context, path, "1. Initialization",
								event,
								"1. Initialization#1. Initialization#e101#true");

						fireComeToState(context, path, "1. Initialization");

						// 1. Initialization [o1.z6]
						fireBeforeOutputActionExecution(
								context,
								path,
								"1. Initialization#1. Initialization#e101#true",
								"o1.z6");

						o1.z6(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"1. Initialization#1. Initialization#e101#true",
								"o1.z6");
						return new StateMachineConfig("1. Initialization");

					case e102:

						// 1. Initialization->1. Initialization e102[true]/o1.z6

						fireTransitionCandidate(context, path,
								"1. Initialization", event,
								"1. Initialization#1. Initialization#e102#true");

						fireTransitionFound(context, path, "1. Initialization",
								event,
								"1. Initialization#1. Initialization#e102#true");

						fireBeforeOutputActionExecution(
								context,
								path,
								"1. Initialization#1. Initialization#e102#true",
								"o1.z6");

						o1.z6(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"1. Initialization#1. Initialization#e102#true",
								"o1.z6");

						fireComeToState(context, path, "1. Initialization");

						// 1. Initialization [o1.z6]
						fireBeforeOutputActionExecution(
								context,
								path,
								"1. Initialization#1. Initialization#e102#true",
								"o1.z6");

						o1.z6(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"1. Initialization#1. Initialization#e102#true",
								"o1.z6");
						return new StateMachineConfig("1. Initialization");

					default:

						// transition not found
						return config;
					}

				case _4__Putting_new_rails:

					switch (e) {
					case e203:

						// 4. Putting new rails->2. Moving forward e203[o1.x1>0]/o2.z4

						fireTransitionCandidate(context, path,
								"4. Putting new rails", event,
								"4. Putting new rails#2. Moving forward#e203#o1.x1>0");

						if (!isInputActionCalculated(calculatedInputActions,
								_o1_x1)) {

							fireBeforeInputActionExecution(
									context,
									path,
									"4. Putting new rails#2. Moving forward#e203#o1.x1>0",
									"o1.x1");

							o1_x1 = o1.x1(context);

							fireAfterInputActionExecution(
									context,
									path,
									"4. Putting new rails#2. Moving forward#e203#o1.x1>0",
									"o1.x1", new Integer(o1_x1));
						}

						if (o1_x1 > 0) {

							fireTransitionFound(context, path,
									"4. Putting new rails", event,
									"4. Putting new rails#2. Moving forward#e203#o1.x1>0");

							fireBeforeOutputActionExecution(
									context,
									path,
									"4. Putting new rails#2. Moving forward#e203#o1.x1>0",
									"o2.z4");

							o2.z4(context);

							fireAfterOutputActionExecution(
									context,
									path,
									"4. Putting new rails#2. Moving forward#e203#o1.x1>0",
									"o2.z4");

							fireComeToState(context, path, "2. Moving forward");

							// 2. Moving forward [o1.z1]
							fireBeforeOutputActionExecution(
									context,
									path,
									"4. Putting new rails#2. Moving forward#e203#o1.x1>0",
									"o1.z1");

							o1.z1(context);

							fireAfterOutputActionExecution(
									context,
									path,
									"4. Putting new rails#2. Moving forward#e203#o1.x1>0",
									"o1.z1");
							return new StateMachineConfig("2. Moving forward");

						}
						// 4. Putting new rails->5. Moving backward e203[o1.x1<=0]/o2.z4

						fireTransitionCandidate(context, path,
								"4. Putting new rails", event,
								"4. Putting new rails#5. Moving backward#e203#o1.x1<=0");

						if (o1_x1 <= 0) {

							fireTransitionFound(context, path,
									"4. Putting new rails", event,
									"4. Putting new rails#5. Moving backward#e203#o1.x1<=0");

							fireBeforeOutputActionExecution(
									context,
									path,
									"4. Putting new rails#5. Moving backward#e203#o1.x1<=0",
									"o2.z4");

							o2.z4(context);

							fireAfterOutputActionExecution(
									context,
									path,
									"4. Putting new rails#5. Moving backward#e203#o1.x1<=0",
									"o2.z4");

							fireComeToState(context, path, "5. Moving backward");

							// 5. Moving backward [o1.z2]
							fireBeforeOutputActionExecution(
									context,
									path,
									"4. Putting new rails#5. Moving backward#e203#o1.x1<=0",
									"o1.z2");

							o1.z2(context);

							fireAfterOutputActionExecution(
									context,
									path,
									"4. Putting new rails#5. Moving backward#e203#o1.x1<=0",
									"o1.z2");
							return new StateMachineConfig("5. Moving backward");

						}

						// transition not found
						return config;
					case e101:

						// 4. Putting new rails->4. Putting new rails e101[true]/

						fireTransitionCandidate(context, path,
								"4. Putting new rails", event,
								"4. Putting new rails#4. Putting new rails#e101#true");

						fireTransitionFound(context, path,
								"4. Putting new rails", event,
								"4. Putting new rails#4. Putting new rails#e101#true");

						fireComeToState(context, path, "4. Putting new rails");

						// 4. Putting new rails [o1.z3]
						fireBeforeOutputActionExecution(
								context,
								path,
								"4. Putting new rails#4. Putting new rails#e101#true",
								"o1.z3");

						o1.z3(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"4. Putting new rails#4. Putting new rails#e101#true",
								"o1.z3");
						return new StateMachineConfig("4. Putting new rails");

					case e102:

						// 4. Putting new rails->1. Initialization e102[true]/

						fireTransitionCandidate(context, path,
								"4. Putting new rails", event,
								"4. Putting new rails#1. Initialization#e102#true");

						fireTransitionFound(context, path,
								"4. Putting new rails", event,
								"4. Putting new rails#1. Initialization#e102#true");

						fireComeToState(context, path, "1. Initialization");

						// 1. Initialization [o1.z6]
						fireBeforeOutputActionExecution(
								context,
								path,
								"4. Putting new rails#1. Initialization#e102#true",
								"o1.z6");

						o1.z6(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"4. Putting new rails#1. Initialization#e102#true",
								"o1.z6");
						return new StateMachineConfig("1. Initialization");

					default:

						// transition not found
						return config;
					}

				case _5__Moving_backward:

					switch (e) {
					case e203:

						// 5. Moving backward->5. Moving backward e203[true]/o2.z4

						fireTransitionCandidate(context, path,
								"5. Moving backward", event,
								"5. Moving backward#5. Moving backward#e203#true");

						fireTransitionFound(context, path,
								"5. Moving backward", event,
								"5. Moving backward#5. Moving backward#e203#true");

						fireBeforeOutputActionExecution(
								context,
								path,
								"5. Moving backward#5. Moving backward#e203#true",
								"o2.z4");

						o2.z4(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"5. Moving backward#5. Moving backward#e203#true",
								"o2.z4");

						fireComeToState(context, path, "5. Moving backward");

						// 5. Moving backward [o1.z2]
						fireBeforeOutputActionExecution(
								context,
								path,
								"5. Moving backward#5. Moving backward#e203#true",
								"o1.z2");

						o1.z2(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"5. Moving backward#5. Moving backward#e203#true",
								"o1.z2");
						return new StateMachineConfig("5. Moving backward");

					case e101:

						// 5. Moving backward->5. Moving backward e101[true]/

						fireTransitionCandidate(context, path,
								"5. Moving backward", event,
								"5. Moving backward#5. Moving backward#e101#true");

						fireTransitionFound(context, path,
								"5. Moving backward", event,
								"5. Moving backward#5. Moving backward#e101#true");

						fireComeToState(context, path, "5. Moving backward");

						// 5. Moving backward [o1.z2]
						fireBeforeOutputActionExecution(
								context,
								path,
								"5. Moving backward#5. Moving backward#e101#true",
								"o1.z2");

						o1.z2(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"5. Moving backward#5. Moving backward#e101#true",
								"o1.z2");
						return new StateMachineConfig("5. Moving backward");

					case e202:

						// 5. Moving backward->6. Loading e202[true]/

						fireTransitionCandidate(context, path,
								"5. Moving backward", event,
								"5. Moving backward#6. Loading#e202#true");

						fireTransitionFound(context, path,
								"5. Moving backward", event,
								"5. Moving backward#6. Loading#e202#true");

						fireComeToState(context, path, "6. Loading");

						// 6. Loading [o1.z5]
						fireBeforeOutputActionExecution(context, path,
								"5. Moving backward#6. Loading#e202#true",
								"o1.z5");

						o1.z5(context);

						fireAfterOutputActionExecution(context, path,
								"5. Moving backward#6. Loading#e202#true",
								"o1.z5");
						return new StateMachineConfig("6. Loading");

					case e102:

						// 5. Moving backward->1. Initialization e102[true]/

						fireTransitionCandidate(context, path,
								"5. Moving backward", event,
								"5. Moving backward#1. Initialization#e102#true");

						fireTransitionFound(context, path,
								"5. Moving backward", event,
								"5. Moving backward#1. Initialization#e102#true");

						fireComeToState(context, path, "1. Initialization");

						// 1. Initialization [o1.z6]
						fireBeforeOutputActionExecution(
								context,
								path,
								"5. Moving backward#1. Initialization#e102#true",
								"o1.z6");

						o1.z6(context);

						fireAfterOutputActionExecution(
								context,
								path,
								"5. Moving backward#1. Initialization#e102#true",
								"o1.z6");
						return new StateMachineConfig("1. Initialization");

					default:

						// transition not found
						return config;
					}

				default:
					throw new EventProcessorException(
							"Incorrect stable state ["
									+ config.getActiveState()
									+ "] in state machine [A2]");
				}
			}
		}

		//o1.x1
		private static final int _o1_x1 = 0;

	}

	private static boolean isInputActionCalculated(
			BitSet calculatedInputActions, int k) {
		boolean b = calculatedInputActions.get(k);

		if (!b) {
			calculatedInputActions.set(k);
		}

		return b;
	}

}
